# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpc4bmi/bmi.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='grpc4bmi/bmi.proto',
  package='bmi',
  syntax='proto3',
  serialized_pb=_b('\n\x12grpc4bmi/bmi.proto\x12\x03\x62mi\"\x07\n\x05\x45mpty\"(\n\x11InitializeRequest\x12\x13\n\x0b\x63onfig_file\x18\x01 \x01(\t\"#\n\x12UpdateUntilRequest\x12\r\n\x05until\x18\x01 \x01(\x01\"!\n\x11UpdateFracRequest\x12\x0c\n\x04\x66rac\x18\x01 \x01(\x01\"(\n\x18GetComponentNameResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\"$\n\x13GetVarNamesResponse\x12\r\n\x05names\x18\x01 \x03(\t\"%\n\x14GetTimeUnitsResponse\x12\r\n\x05units\x18\x01 \x01(\t\"\'\n\x13GetTimeStepResponse\x12\x10\n\x08interval\x18\x01 \x01(\x01\"\x1f\n\x0fGetTimeResponse\x12\x0c\n\x04time\x18\x01 \x01(\x01\"\x1d\n\rGetVarRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"%\n\x12GetVarGridResponse\x12\x0f\n\x07grid_id\x18\x01 \x01(\x05\"\"\n\x12GetVarTypeResponse\x12\x0c\n\x04type\x18\x01 \x01(\t\"&\n\x16GetVarItemSizeResponse\x12\x0c\n\x04size\x18\x01 \x01(\x03\"$\n\x13GetVarUnitsResponse\x12\r\n\x05units\x18\x01 \x01(\t\"&\n\x14GetVarNBytesResponse\x12\x0e\n\x06nbytes\x18\x01 \x01(\x03\"%\n\x0fIntArrayMessage\x12\x12\n\x06values\x18\x01 \x03(\x03\x42\x02\x10\x01\"\'\n\x11\x46loatArrayMessage\x12\x12\n\x06values\x18\x01 \x03(\x02\x42\x02\x10\x01\"(\n\x12\x44oubleArrayMessage\x12\x12\n\x06values\x18\x01 \x03(\x01\x42\x02\x10\x01\"\xaa\x01\n\x10GetValueResponse\x12*\n\nvalues_int\x18\x01 \x01(\x0b\x32\x14.bmi.IntArrayMessageH\x00\x12.\n\x0cvalues_float\x18\x02 \x01(\x0b\x32\x16.bmi.FloatArrayMessageH\x00\x12\x30\n\rvalues_double\x18\x03 \x01(\x0b\x32\x17.bmi.DoubleArrayMessageH\x00\x42\x08\n\x06values\"=\n\x18GetValueAtIndicesRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x07indices\x18\x02 \x03(\x03\x42\x02\x10\x01\"\xb3\x01\n\x19GetValueAtIndicesResponse\x12*\n\nvalues_int\x18\x01 \x01(\x0b\x32\x14.bmi.IntArrayMessageH\x00\x12.\n\x0cvalues_float\x18\x02 \x01(\x0b\x32\x16.bmi.FloatArrayMessageH\x00\x12\x30\n\rvalues_double\x18\x03 \x01(\x0b\x32\x17.bmi.DoubleArrayMessageH\x00\x42\x08\n\x06values\"\xb7\x01\n\x0fSetValueRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\nvalues_int\x18\x02 \x01(\x0b\x32\x14.bmi.IntArrayMessageH\x00\x12.\n\x0cvalues_float\x18\x03 \x01(\x0b\x32\x16.bmi.FloatArrayMessageH\x00\x12\x30\n\rvalues_double\x18\x04 \x01(\x0b\x32\x17.bmi.DoubleArrayMessageH\x00\x42\x08\n\x06values\"/\n\x12SetValuePtrRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03ref\x18\x02 \x01(\x03\"\xd5\x01\n\x18SetValueAtIndicesRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x07indices\x18\x02 \x03(\x03\x42\x02\x10\x01\x12*\n\nvalues_int\x18\x03 \x01(\x0b\x32\x14.bmi.IntArrayMessageH\x00\x12.\n\x0cvalues_float\x18\x04 \x01(\x0b\x32\x16.bmi.FloatArrayMessageH\x00\x12\x30\n\rvalues_double\x18\x05 \x01(\x0b\x32\x17.bmi.DoubleArrayMessageH\x00\x42\x08\n\x06values\"\x1e\n\x0bGridRequest\x12\x0f\n\x07grid_id\x18\x01 \x01(\x03\"#\n\x13GetGridSizeResponse\x12\x0c\n\x04size\x18\x01 \x01(\x03\"#\n\x13GetGridRankResponse\x12\x0c\n\x04rank\x18\x01 \x01(\x03\"#\n\x13GetGridTypeResponse\x12\x0c\n\x04type\x18\x01 \x01(\t\")\n\x14GetGridShapeResponse\x12\x11\n\x05shape\x18\x01 \x03(\x03\x42\x02\x10\x01\"-\n\x16GetGridSpacingResponse\x12\x13\n\x07spacing\x18\x01 \x03(\x01\x42\x02\x10\x01\"+\n\x15GetGridOriginResponse\x12\x12\n\x06origin\x18\x01 \x03(\x01\x42\x02\x10\x01\"0\n\x15GetGridPointsResponse\x12\x17\n\x0b\x63oordinates\x18\x01 \x03(\x01\x42\x02\x10\x01\"0\n\x1bGetGridConnectivityResponse\x12\x11\n\x05links\x18\x01 \x03(\x03\x42\x02\x10\x01\",\n\x15GetGridOffsetResponse\x12\x13\n\x07offsets\x18\x01 \x03(\x03\x42\x02\x10\x01\x32\xb6\x0f\n\nBmiService\x12\x32\n\ninitialize\x12\x16.bmi.InitializeRequest\x1a\n.bmi.Empty\"\x00\x12\"\n\x06update\x12\n.bmi.Empty\x1a\n.bmi.Empty\"\x00\x12\x34\n\x0bupdateUntil\x12\x17.bmi.UpdateUntilRequest\x1a\n.bmi.Empty\"\x00\x12\x32\n\nupdateFrac\x12\x16.bmi.UpdateFracRequest\x1a\n.bmi.Empty\"\x00\x12$\n\x08\x66inalize\x12\n.bmi.Empty\x1a\n.bmi.Empty\"\x00\x12?\n\x10getComponentName\x12\n.bmi.Empty\x1a\x1d.bmi.GetComponentNameResponse\"\x00\x12:\n\x10getInputVarNames\x12\n.bmi.Empty\x1a\x18.bmi.GetVarNamesResponse\"\x00\x12;\n\x11getOutputVarNames\x12\n.bmi.Empty\x1a\x18.bmi.GetVarNamesResponse\"\x00\x12\x37\n\x0cgetTimeUnits\x12\n.bmi.Empty\x1a\x19.bmi.GetTimeUnitsResponse\"\x00\x12\x35\n\x0bgetTimeStep\x12\n.bmi.Empty\x1a\x18.bmi.GetTimeStepResponse\"\x00\x12\x34\n\x0egetCurrentTime\x12\n.bmi.Empty\x1a\x14.bmi.GetTimeResponse\"\x00\x12\x32\n\x0cgetStartTime\x12\n.bmi.Empty\x1a\x14.bmi.GetTimeResponse\"\x00\x12\x30\n\ngetEndTime\x12\n.bmi.Empty\x1a\x14.bmi.GetTimeResponse\"\x00\x12;\n\ngetVarGrid\x12\x12.bmi.GetVarRequest\x1a\x17.bmi.GetVarGridResponse\"\x00\x12;\n\ngetVarType\x12\x12.bmi.GetVarRequest\x1a\x17.bmi.GetVarTypeResponse\"\x00\x12\x43\n\x0egetVarItemSize\x12\x12.bmi.GetVarRequest\x1a\x1b.bmi.GetVarItemSizeResponse\"\x00\x12=\n\x0bgetVarUnits\x12\x12.bmi.GetVarRequest\x1a\x18.bmi.GetVarUnitsResponse\"\x00\x12?\n\x0cgetVarNBytes\x12\x12.bmi.GetVarRequest\x1a\x19.bmi.GetVarNBytesResponse\"\x00\x12\x37\n\x08getValue\x12\x12.bmi.GetVarRequest\x1a\x15.bmi.GetValueResponse\"\x00\x12T\n\x11getValueAtIndices\x12\x1d.bmi.GetValueAtIndicesRequest\x1a\x1e.bmi.GetValueAtIndicesResponse\"\x00\x12.\n\x08setValue\x12\x14.bmi.SetValueRequest\x1a\n.bmi.Empty\"\x00\x12@\n\x11setValueAtIndices\x12\x1d.bmi.SetValueAtIndicesRequest\x1a\n.bmi.Empty\"\x00\x12;\n\x0bgetGridSize\x12\x10.bmi.GridRequest\x1a\x18.bmi.GetGridSizeResponse\"\x00\x12;\n\x0bgetGridType\x12\x10.bmi.GridRequest\x1a\x18.bmi.GetGridTypeResponse\"\x00\x12;\n\x0bgetGridRank\x12\x10.bmi.GridRequest\x1a\x18.bmi.GetGridRankResponse\"\x00\x12=\n\x0cgetGridShape\x12\x10.bmi.GridRequest\x1a\x19.bmi.GetGridShapeResponse\"\x00\x12\x41\n\x0egetGridSpacing\x12\x10.bmi.GridRequest\x1a\x1b.bmi.GetGridSpacingResponse\"\x00\x12?\n\rgetGridOrigin\x12\x10.bmi.GridRequest\x1a\x1a.bmi.GetGridOriginResponse\"\x00\x12:\n\x08getGridX\x12\x10.bmi.GridRequest\x1a\x1a.bmi.GetGridPointsResponse\"\x00\x12:\n\x08getGridY\x12\x10.bmi.GridRequest\x1a\x1a.bmi.GetGridPointsResponse\"\x00\x12:\n\x08getGridZ\x12\x10.bmi.GridRequest\x1a\x1a.bmi.GetGridPointsResponse\"\x00\x12K\n\x13getGridConnectivity\x12\x10.bmi.GridRequest\x1a .bmi.GetGridConnectivityResponse\"\x00\x12?\n\rgetGridOffset\x12\x10.bmi.GridRequest\x1a\x1a.bmi.GetGridOffsetResponse\"\x00\x62\x06proto3')
)




_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='bmi.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=34,
)


_INITIALIZEREQUEST = _descriptor.Descriptor(
  name='InitializeRequest',
  full_name='bmi.InitializeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='config_file', full_name='bmi.InitializeRequest.config_file', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=76,
)


_UPDATEUNTILREQUEST = _descriptor.Descriptor(
  name='UpdateUntilRequest',
  full_name='bmi.UpdateUntilRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='until', full_name='bmi.UpdateUntilRequest.until', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=113,
)


_UPDATEFRACREQUEST = _descriptor.Descriptor(
  name='UpdateFracRequest',
  full_name='bmi.UpdateFracRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='frac', full_name='bmi.UpdateFracRequest.frac', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=148,
)


_GETCOMPONENTNAMERESPONSE = _descriptor.Descriptor(
  name='GetComponentNameResponse',
  full_name='bmi.GetComponentNameResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bmi.GetComponentNameResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=190,
)


_GETVARNAMESRESPONSE = _descriptor.Descriptor(
  name='GetVarNamesResponse',
  full_name='bmi.GetVarNamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='bmi.GetVarNamesResponse.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=228,
)


_GETTIMEUNITSRESPONSE = _descriptor.Descriptor(
  name='GetTimeUnitsResponse',
  full_name='bmi.GetTimeUnitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='bmi.GetTimeUnitsResponse.units', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=230,
  serialized_end=267,
)


_GETTIMESTEPRESPONSE = _descriptor.Descriptor(
  name='GetTimeStepResponse',
  full_name='bmi.GetTimeStepResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='bmi.GetTimeStepResponse.interval', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=269,
  serialized_end=308,
)


_GETTIMERESPONSE = _descriptor.Descriptor(
  name='GetTimeResponse',
  full_name='bmi.GetTimeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='bmi.GetTimeResponse.time', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=341,
)


_GETVARREQUEST = _descriptor.Descriptor(
  name='GetVarRequest',
  full_name='bmi.GetVarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bmi.GetVarRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=372,
)


_GETVARGRIDRESPONSE = _descriptor.Descriptor(
  name='GetVarGridResponse',
  full_name='bmi.GetVarGridResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='grid_id', full_name='bmi.GetVarGridResponse.grid_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=374,
  serialized_end=411,
)


_GETVARTYPERESPONSE = _descriptor.Descriptor(
  name='GetVarTypeResponse',
  full_name='bmi.GetVarTypeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='bmi.GetVarTypeResponse.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=447,
)


_GETVARITEMSIZERESPONSE = _descriptor.Descriptor(
  name='GetVarItemSizeResponse',
  full_name='bmi.GetVarItemSizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bmi.GetVarItemSizeResponse.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=487,
)


_GETVARUNITSRESPONSE = _descriptor.Descriptor(
  name='GetVarUnitsResponse',
  full_name='bmi.GetVarUnitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='units', full_name='bmi.GetVarUnitsResponse.units', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=525,
)


_GETVARNBYTESRESPONSE = _descriptor.Descriptor(
  name='GetVarNBytesResponse',
  full_name='bmi.GetVarNBytesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nbytes', full_name='bmi.GetVarNBytesResponse.nbytes', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=527,
  serialized_end=565,
)


_INTARRAYMESSAGE = _descriptor.Descriptor(
  name='IntArrayMessage',
  full_name='bmi.IntArrayMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='bmi.IntArrayMessage.values', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=567,
  serialized_end=604,
)


_FLOATARRAYMESSAGE = _descriptor.Descriptor(
  name='FloatArrayMessage',
  full_name='bmi.FloatArrayMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='bmi.FloatArrayMessage.values', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=606,
  serialized_end=645,
)


_DOUBLEARRAYMESSAGE = _descriptor.Descriptor(
  name='DoubleArrayMessage',
  full_name='bmi.DoubleArrayMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='bmi.DoubleArrayMessage.values', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=647,
  serialized_end=687,
)


_GETVALUERESPONSE = _descriptor.Descriptor(
  name='GetValueResponse',
  full_name='bmi.GetValueResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values_int', full_name='bmi.GetValueResponse.values_int', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_float', full_name='bmi.GetValueResponse.values_float', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_double', full_name='bmi.GetValueResponse.values_double', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='values', full_name='bmi.GetValueResponse.values',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=690,
  serialized_end=860,
)


_GETVALUEATINDICESREQUEST = _descriptor.Descriptor(
  name='GetValueAtIndicesRequest',
  full_name='bmi.GetValueAtIndicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bmi.GetValueAtIndicesRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indices', full_name='bmi.GetValueAtIndicesRequest.indices', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=862,
  serialized_end=923,
)


_GETVALUEATINDICESRESPONSE = _descriptor.Descriptor(
  name='GetValueAtIndicesResponse',
  full_name='bmi.GetValueAtIndicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values_int', full_name='bmi.GetValueAtIndicesResponse.values_int', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_float', full_name='bmi.GetValueAtIndicesResponse.values_float', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_double', full_name='bmi.GetValueAtIndicesResponse.values_double', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='values', full_name='bmi.GetValueAtIndicesResponse.values',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=926,
  serialized_end=1105,
)


_SETVALUEREQUEST = _descriptor.Descriptor(
  name='SetValueRequest',
  full_name='bmi.SetValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bmi.SetValueRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_int', full_name='bmi.SetValueRequest.values_int', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_float', full_name='bmi.SetValueRequest.values_float', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_double', full_name='bmi.SetValueRequest.values_double', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='values', full_name='bmi.SetValueRequest.values',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1108,
  serialized_end=1291,
)


_SETVALUEPTRREQUEST = _descriptor.Descriptor(
  name='SetValuePtrRequest',
  full_name='bmi.SetValuePtrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bmi.SetValuePtrRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref', full_name='bmi.SetValuePtrRequest.ref', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1293,
  serialized_end=1340,
)


_SETVALUEATINDICESREQUEST = _descriptor.Descriptor(
  name='SetValueAtIndicesRequest',
  full_name='bmi.SetValueAtIndicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='bmi.SetValueAtIndicesRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indices', full_name='bmi.SetValueAtIndicesRequest.indices', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_int', full_name='bmi.SetValueAtIndicesRequest.values_int', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_float', full_name='bmi.SetValueAtIndicesRequest.values_float', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values_double', full_name='bmi.SetValueAtIndicesRequest.values_double', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='values', full_name='bmi.SetValueAtIndicesRequest.values',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1343,
  serialized_end=1556,
)


_GRIDREQUEST = _descriptor.Descriptor(
  name='GridRequest',
  full_name='bmi.GridRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='grid_id', full_name='bmi.GridRequest.grid_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1558,
  serialized_end=1588,
)


_GETGRIDSIZERESPONSE = _descriptor.Descriptor(
  name='GetGridSizeResponse',
  full_name='bmi.GetGridSizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='bmi.GetGridSizeResponse.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1590,
  serialized_end=1625,
)


_GETGRIDRANKRESPONSE = _descriptor.Descriptor(
  name='GetGridRankResponse',
  full_name='bmi.GetGridRankResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank', full_name='bmi.GetGridRankResponse.rank', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1627,
  serialized_end=1662,
)


_GETGRIDTYPERESPONSE = _descriptor.Descriptor(
  name='GetGridTypeResponse',
  full_name='bmi.GetGridTypeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='bmi.GetGridTypeResponse.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1699,
)


_GETGRIDSHAPERESPONSE = _descriptor.Descriptor(
  name='GetGridShapeResponse',
  full_name='bmi.GetGridShapeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='bmi.GetGridShapeResponse.shape', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1701,
  serialized_end=1742,
)


_GETGRIDSPACINGRESPONSE = _descriptor.Descriptor(
  name='GetGridSpacingResponse',
  full_name='bmi.GetGridSpacingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spacing', full_name='bmi.GetGridSpacingResponse.spacing', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1744,
  serialized_end=1789,
)


_GETGRIDORIGINRESPONSE = _descriptor.Descriptor(
  name='GetGridOriginResponse',
  full_name='bmi.GetGridOriginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='bmi.GetGridOriginResponse.origin', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1791,
  serialized_end=1834,
)


_GETGRIDPOINTSRESPONSE = _descriptor.Descriptor(
  name='GetGridPointsResponse',
  full_name='bmi.GetGridPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='bmi.GetGridPointsResponse.coordinates', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1836,
  serialized_end=1884,
)


_GETGRIDCONNECTIVITYRESPONSE = _descriptor.Descriptor(
  name='GetGridConnectivityResponse',
  full_name='bmi.GetGridConnectivityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='links', full_name='bmi.GetGridConnectivityResponse.links', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1886,
  serialized_end=1934,
)


_GETGRIDOFFSETRESPONSE = _descriptor.Descriptor(
  name='GetGridOffsetResponse',
  full_name='bmi.GetGridOffsetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offsets', full_name='bmi.GetGridOffsetResponse.offsets', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1936,
  serialized_end=1980,
)

_GETVALUERESPONSE.fields_by_name['values_int'].message_type = _INTARRAYMESSAGE
_GETVALUERESPONSE.fields_by_name['values_float'].message_type = _FLOATARRAYMESSAGE
_GETVALUERESPONSE.fields_by_name['values_double'].message_type = _DOUBLEARRAYMESSAGE
_GETVALUERESPONSE.oneofs_by_name['values'].fields.append(
  _GETVALUERESPONSE.fields_by_name['values_int'])
_GETVALUERESPONSE.fields_by_name['values_int'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['values']
_GETVALUERESPONSE.oneofs_by_name['values'].fields.append(
  _GETVALUERESPONSE.fields_by_name['values_float'])
_GETVALUERESPONSE.fields_by_name['values_float'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['values']
_GETVALUERESPONSE.oneofs_by_name['values'].fields.append(
  _GETVALUERESPONSE.fields_by_name['values_double'])
_GETVALUERESPONSE.fields_by_name['values_double'].containing_oneof = _GETVALUERESPONSE.oneofs_by_name['values']
_GETVALUEATINDICESRESPONSE.fields_by_name['values_int'].message_type = _INTARRAYMESSAGE
_GETVALUEATINDICESRESPONSE.fields_by_name['values_float'].message_type = _FLOATARRAYMESSAGE
_GETVALUEATINDICESRESPONSE.fields_by_name['values_double'].message_type = _DOUBLEARRAYMESSAGE
_GETVALUEATINDICESRESPONSE.oneofs_by_name['values'].fields.append(
  _GETVALUEATINDICESRESPONSE.fields_by_name['values_int'])
_GETVALUEATINDICESRESPONSE.fields_by_name['values_int'].containing_oneof = _GETVALUEATINDICESRESPONSE.oneofs_by_name['values']
_GETVALUEATINDICESRESPONSE.oneofs_by_name['values'].fields.append(
  _GETVALUEATINDICESRESPONSE.fields_by_name['values_float'])
_GETVALUEATINDICESRESPONSE.fields_by_name['values_float'].containing_oneof = _GETVALUEATINDICESRESPONSE.oneofs_by_name['values']
_GETVALUEATINDICESRESPONSE.oneofs_by_name['values'].fields.append(
  _GETVALUEATINDICESRESPONSE.fields_by_name['values_double'])
_GETVALUEATINDICESRESPONSE.fields_by_name['values_double'].containing_oneof = _GETVALUEATINDICESRESPONSE.oneofs_by_name['values']
_SETVALUEREQUEST.fields_by_name['values_int'].message_type = _INTARRAYMESSAGE
_SETVALUEREQUEST.fields_by_name['values_float'].message_type = _FLOATARRAYMESSAGE
_SETVALUEREQUEST.fields_by_name['values_double'].message_type = _DOUBLEARRAYMESSAGE
_SETVALUEREQUEST.oneofs_by_name['values'].fields.append(
  _SETVALUEREQUEST.fields_by_name['values_int'])
_SETVALUEREQUEST.fields_by_name['values_int'].containing_oneof = _SETVALUEREQUEST.oneofs_by_name['values']
_SETVALUEREQUEST.oneofs_by_name['values'].fields.append(
  _SETVALUEREQUEST.fields_by_name['values_float'])
_SETVALUEREQUEST.fields_by_name['values_float'].containing_oneof = _SETVALUEREQUEST.oneofs_by_name['values']
_SETVALUEREQUEST.oneofs_by_name['values'].fields.append(
  _SETVALUEREQUEST.fields_by_name['values_double'])
_SETVALUEREQUEST.fields_by_name['values_double'].containing_oneof = _SETVALUEREQUEST.oneofs_by_name['values']
_SETVALUEATINDICESREQUEST.fields_by_name['values_int'].message_type = _INTARRAYMESSAGE
_SETVALUEATINDICESREQUEST.fields_by_name['values_float'].message_type = _FLOATARRAYMESSAGE
_SETVALUEATINDICESREQUEST.fields_by_name['values_double'].message_type = _DOUBLEARRAYMESSAGE
_SETVALUEATINDICESREQUEST.oneofs_by_name['values'].fields.append(
  _SETVALUEATINDICESREQUEST.fields_by_name['values_int'])
_SETVALUEATINDICESREQUEST.fields_by_name['values_int'].containing_oneof = _SETVALUEATINDICESREQUEST.oneofs_by_name['values']
_SETVALUEATINDICESREQUEST.oneofs_by_name['values'].fields.append(
  _SETVALUEATINDICESREQUEST.fields_by_name['values_float'])
_SETVALUEATINDICESREQUEST.fields_by_name['values_float'].containing_oneof = _SETVALUEATINDICESREQUEST.oneofs_by_name['values']
_SETVALUEATINDICESREQUEST.oneofs_by_name['values'].fields.append(
  _SETVALUEATINDICESREQUEST.fields_by_name['values_double'])
_SETVALUEATINDICESREQUEST.fields_by_name['values_double'].containing_oneof = _SETVALUEATINDICESREQUEST.oneofs_by_name['values']
DESCRIPTOR.message_types_by_name['Empty'] = _EMPTY
DESCRIPTOR.message_types_by_name['InitializeRequest'] = _INITIALIZEREQUEST
DESCRIPTOR.message_types_by_name['UpdateUntilRequest'] = _UPDATEUNTILREQUEST
DESCRIPTOR.message_types_by_name['UpdateFracRequest'] = _UPDATEFRACREQUEST
DESCRIPTOR.message_types_by_name['GetComponentNameResponse'] = _GETCOMPONENTNAMERESPONSE
DESCRIPTOR.message_types_by_name['GetVarNamesResponse'] = _GETVARNAMESRESPONSE
DESCRIPTOR.message_types_by_name['GetTimeUnitsResponse'] = _GETTIMEUNITSRESPONSE
DESCRIPTOR.message_types_by_name['GetTimeStepResponse'] = _GETTIMESTEPRESPONSE
DESCRIPTOR.message_types_by_name['GetTimeResponse'] = _GETTIMERESPONSE
DESCRIPTOR.message_types_by_name['GetVarRequest'] = _GETVARREQUEST
DESCRIPTOR.message_types_by_name['GetVarGridResponse'] = _GETVARGRIDRESPONSE
DESCRIPTOR.message_types_by_name['GetVarTypeResponse'] = _GETVARTYPERESPONSE
DESCRIPTOR.message_types_by_name['GetVarItemSizeResponse'] = _GETVARITEMSIZERESPONSE
DESCRIPTOR.message_types_by_name['GetVarUnitsResponse'] = _GETVARUNITSRESPONSE
DESCRIPTOR.message_types_by_name['GetVarNBytesResponse'] = _GETVARNBYTESRESPONSE
DESCRIPTOR.message_types_by_name['IntArrayMessage'] = _INTARRAYMESSAGE
DESCRIPTOR.message_types_by_name['FloatArrayMessage'] = _FLOATARRAYMESSAGE
DESCRIPTOR.message_types_by_name['DoubleArrayMessage'] = _DOUBLEARRAYMESSAGE
DESCRIPTOR.message_types_by_name['GetValueResponse'] = _GETVALUERESPONSE
DESCRIPTOR.message_types_by_name['GetValueAtIndicesRequest'] = _GETVALUEATINDICESREQUEST
DESCRIPTOR.message_types_by_name['GetValueAtIndicesResponse'] = _GETVALUEATINDICESRESPONSE
DESCRIPTOR.message_types_by_name['SetValueRequest'] = _SETVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetValuePtrRequest'] = _SETVALUEPTRREQUEST
DESCRIPTOR.message_types_by_name['SetValueAtIndicesRequest'] = _SETVALUEATINDICESREQUEST
DESCRIPTOR.message_types_by_name['GridRequest'] = _GRIDREQUEST
DESCRIPTOR.message_types_by_name['GetGridSizeResponse'] = _GETGRIDSIZERESPONSE
DESCRIPTOR.message_types_by_name['GetGridRankResponse'] = _GETGRIDRANKRESPONSE
DESCRIPTOR.message_types_by_name['GetGridTypeResponse'] = _GETGRIDTYPERESPONSE
DESCRIPTOR.message_types_by_name['GetGridShapeResponse'] = _GETGRIDSHAPERESPONSE
DESCRIPTOR.message_types_by_name['GetGridSpacingResponse'] = _GETGRIDSPACINGRESPONSE
DESCRIPTOR.message_types_by_name['GetGridOriginResponse'] = _GETGRIDORIGINRESPONSE
DESCRIPTOR.message_types_by_name['GetGridPointsResponse'] = _GETGRIDPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['GetGridConnectivityResponse'] = _GETGRIDCONNECTIVITYRESPONSE
DESCRIPTOR.message_types_by_name['GetGridOffsetResponse'] = _GETGRIDOFFSETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Empty = _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), dict(
  DESCRIPTOR = _EMPTY,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.Empty)
  ))
_sym_db.RegisterMessage(Empty)

InitializeRequest = _reflection.GeneratedProtocolMessageType('InitializeRequest', (_message.Message,), dict(
  DESCRIPTOR = _INITIALIZEREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.InitializeRequest)
  ))
_sym_db.RegisterMessage(InitializeRequest)

UpdateUntilRequest = _reflection.GeneratedProtocolMessageType('UpdateUntilRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEUNTILREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.UpdateUntilRequest)
  ))
_sym_db.RegisterMessage(UpdateUntilRequest)

UpdateFracRequest = _reflection.GeneratedProtocolMessageType('UpdateFracRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPDATEFRACREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.UpdateFracRequest)
  ))
_sym_db.RegisterMessage(UpdateFracRequest)

GetComponentNameResponse = _reflection.GeneratedProtocolMessageType('GetComponentNameResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETCOMPONENTNAMERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetComponentNameResponse)
  ))
_sym_db.RegisterMessage(GetComponentNameResponse)

GetVarNamesResponse = _reflection.GeneratedProtocolMessageType('GetVarNamesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVARNAMESRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarNamesResponse)
  ))
_sym_db.RegisterMessage(GetVarNamesResponse)

GetTimeUnitsResponse = _reflection.GeneratedProtocolMessageType('GetTimeUnitsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTIMEUNITSRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetTimeUnitsResponse)
  ))
_sym_db.RegisterMessage(GetTimeUnitsResponse)

GetTimeStepResponse = _reflection.GeneratedProtocolMessageType('GetTimeStepResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTIMESTEPRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetTimeStepResponse)
  ))
_sym_db.RegisterMessage(GetTimeStepResponse)

GetTimeResponse = _reflection.GeneratedProtocolMessageType('GetTimeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETTIMERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetTimeResponse)
  ))
_sym_db.RegisterMessage(GetTimeResponse)

GetVarRequest = _reflection.GeneratedProtocolMessageType('GetVarRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETVARREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarRequest)
  ))
_sym_db.RegisterMessage(GetVarRequest)

GetVarGridResponse = _reflection.GeneratedProtocolMessageType('GetVarGridResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVARGRIDRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarGridResponse)
  ))
_sym_db.RegisterMessage(GetVarGridResponse)

GetVarTypeResponse = _reflection.GeneratedProtocolMessageType('GetVarTypeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVARTYPERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarTypeResponse)
  ))
_sym_db.RegisterMessage(GetVarTypeResponse)

GetVarItemSizeResponse = _reflection.GeneratedProtocolMessageType('GetVarItemSizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVARITEMSIZERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarItemSizeResponse)
  ))
_sym_db.RegisterMessage(GetVarItemSizeResponse)

GetVarUnitsResponse = _reflection.GeneratedProtocolMessageType('GetVarUnitsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVARUNITSRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarUnitsResponse)
  ))
_sym_db.RegisterMessage(GetVarUnitsResponse)

GetVarNBytesResponse = _reflection.GeneratedProtocolMessageType('GetVarNBytesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVARNBYTESRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetVarNBytesResponse)
  ))
_sym_db.RegisterMessage(GetVarNBytesResponse)

IntArrayMessage = _reflection.GeneratedProtocolMessageType('IntArrayMessage', (_message.Message,), dict(
  DESCRIPTOR = _INTARRAYMESSAGE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.IntArrayMessage)
  ))
_sym_db.RegisterMessage(IntArrayMessage)

FloatArrayMessage = _reflection.GeneratedProtocolMessageType('FloatArrayMessage', (_message.Message,), dict(
  DESCRIPTOR = _FLOATARRAYMESSAGE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.FloatArrayMessage)
  ))
_sym_db.RegisterMessage(FloatArrayMessage)

DoubleArrayMessage = _reflection.GeneratedProtocolMessageType('DoubleArrayMessage', (_message.Message,), dict(
  DESCRIPTOR = _DOUBLEARRAYMESSAGE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.DoubleArrayMessage)
  ))
_sym_db.RegisterMessage(DoubleArrayMessage)

GetValueResponse = _reflection.GeneratedProtocolMessageType('GetValueResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVALUERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetValueResponse)
  ))
_sym_db.RegisterMessage(GetValueResponse)

GetValueAtIndicesRequest = _reflection.GeneratedProtocolMessageType('GetValueAtIndicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETVALUEATINDICESREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetValueAtIndicesRequest)
  ))
_sym_db.RegisterMessage(GetValueAtIndicesRequest)

GetValueAtIndicesResponse = _reflection.GeneratedProtocolMessageType('GetValueAtIndicesResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETVALUEATINDICESRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetValueAtIndicesResponse)
  ))
_sym_db.RegisterMessage(GetValueAtIndicesResponse)

SetValueRequest = _reflection.GeneratedProtocolMessageType('SetValueRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETVALUEREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.SetValueRequest)
  ))
_sym_db.RegisterMessage(SetValueRequest)

SetValuePtrRequest = _reflection.GeneratedProtocolMessageType('SetValuePtrRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETVALUEPTRREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.SetValuePtrRequest)
  ))
_sym_db.RegisterMessage(SetValuePtrRequest)

SetValueAtIndicesRequest = _reflection.GeneratedProtocolMessageType('SetValueAtIndicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETVALUEATINDICESREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.SetValueAtIndicesRequest)
  ))
_sym_db.RegisterMessage(SetValueAtIndicesRequest)

GridRequest = _reflection.GeneratedProtocolMessageType('GridRequest', (_message.Message,), dict(
  DESCRIPTOR = _GRIDREQUEST,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GridRequest)
  ))
_sym_db.RegisterMessage(GridRequest)

GetGridSizeResponse = _reflection.GeneratedProtocolMessageType('GetGridSizeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDSIZERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridSizeResponse)
  ))
_sym_db.RegisterMessage(GetGridSizeResponse)

GetGridRankResponse = _reflection.GeneratedProtocolMessageType('GetGridRankResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDRANKRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridRankResponse)
  ))
_sym_db.RegisterMessage(GetGridRankResponse)

GetGridTypeResponse = _reflection.GeneratedProtocolMessageType('GetGridTypeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDTYPERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridTypeResponse)
  ))
_sym_db.RegisterMessage(GetGridTypeResponse)

GetGridShapeResponse = _reflection.GeneratedProtocolMessageType('GetGridShapeResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDSHAPERESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridShapeResponse)
  ))
_sym_db.RegisterMessage(GetGridShapeResponse)

GetGridSpacingResponse = _reflection.GeneratedProtocolMessageType('GetGridSpacingResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDSPACINGRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridSpacingResponse)
  ))
_sym_db.RegisterMessage(GetGridSpacingResponse)

GetGridOriginResponse = _reflection.GeneratedProtocolMessageType('GetGridOriginResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDORIGINRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridOriginResponse)
  ))
_sym_db.RegisterMessage(GetGridOriginResponse)

GetGridPointsResponse = _reflection.GeneratedProtocolMessageType('GetGridPointsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDPOINTSRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridPointsResponse)
  ))
_sym_db.RegisterMessage(GetGridPointsResponse)

GetGridConnectivityResponse = _reflection.GeneratedProtocolMessageType('GetGridConnectivityResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDCONNECTIVITYRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridConnectivityResponse)
  ))
_sym_db.RegisterMessage(GetGridConnectivityResponse)

GetGridOffsetResponse = _reflection.GeneratedProtocolMessageType('GetGridOffsetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETGRIDOFFSETRESPONSE,
  __module__ = 'grpc4bmi.bmi_pb2'
  # @@protoc_insertion_point(class_scope:bmi.GetGridOffsetResponse)
  ))
_sym_db.RegisterMessage(GetGridOffsetResponse)


_INTARRAYMESSAGE.fields_by_name['values'].has_options = True
_INTARRAYMESSAGE.fields_by_name['values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_FLOATARRAYMESSAGE.fields_by_name['values'].has_options = True
_FLOATARRAYMESSAGE.fields_by_name['values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_DOUBLEARRAYMESSAGE.fields_by_name['values'].has_options = True
_DOUBLEARRAYMESSAGE.fields_by_name['values']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETVALUEATINDICESREQUEST.fields_by_name['indices'].has_options = True
_GETVALUEATINDICESREQUEST.fields_by_name['indices']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_SETVALUEATINDICESREQUEST.fields_by_name['indices'].has_options = True
_SETVALUEATINDICESREQUEST.fields_by_name['indices']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETGRIDSHAPERESPONSE.fields_by_name['shape'].has_options = True
_GETGRIDSHAPERESPONSE.fields_by_name['shape']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETGRIDSPACINGRESPONSE.fields_by_name['spacing'].has_options = True
_GETGRIDSPACINGRESPONSE.fields_by_name['spacing']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETGRIDORIGINRESPONSE.fields_by_name['origin'].has_options = True
_GETGRIDORIGINRESPONSE.fields_by_name['origin']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETGRIDPOINTSRESPONSE.fields_by_name['coordinates'].has_options = True
_GETGRIDPOINTSRESPONSE.fields_by_name['coordinates']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETGRIDCONNECTIVITYRESPONSE.fields_by_name['links'].has_options = True
_GETGRIDCONNECTIVITYRESPONSE.fields_by_name['links']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))
_GETGRIDOFFSETRESPONSE.fields_by_name['offsets'].has_options = True
_GETGRIDOFFSETRESPONSE.fields_by_name['offsets']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\020\001'))

_BMISERVICE = _descriptor.ServiceDescriptor(
  name='BmiService',
  full_name='bmi.BmiService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1983,
  serialized_end=3957,
  methods=[
  _descriptor.MethodDescriptor(
    name='initialize',
    full_name='bmi.BmiService.initialize',
    index=0,
    containing_service=None,
    input_type=_INITIALIZEREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='update',
    full_name='bmi.BmiService.update',
    index=1,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='updateUntil',
    full_name='bmi.BmiService.updateUntil',
    index=2,
    containing_service=None,
    input_type=_UPDATEUNTILREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='updateFrac',
    full_name='bmi.BmiService.updateFrac',
    index=3,
    containing_service=None,
    input_type=_UPDATEFRACREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='finalize',
    full_name='bmi.BmiService.finalize',
    index=4,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getComponentName',
    full_name='bmi.BmiService.getComponentName',
    index=5,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETCOMPONENTNAMERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getInputVarNames',
    full_name='bmi.BmiService.getInputVarNames',
    index=6,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETVARNAMESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getOutputVarNames',
    full_name='bmi.BmiService.getOutputVarNames',
    index=7,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETVARNAMESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getTimeUnits',
    full_name='bmi.BmiService.getTimeUnits',
    index=8,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETTIMEUNITSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getTimeStep',
    full_name='bmi.BmiService.getTimeStep',
    index=9,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETTIMESTEPRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getCurrentTime',
    full_name='bmi.BmiService.getCurrentTime',
    index=10,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETTIMERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getStartTime',
    full_name='bmi.BmiService.getStartTime',
    index=11,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETTIMERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getEndTime',
    full_name='bmi.BmiService.getEndTime',
    index=12,
    containing_service=None,
    input_type=_EMPTY,
    output_type=_GETTIMERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getVarGrid',
    full_name='bmi.BmiService.getVarGrid',
    index=13,
    containing_service=None,
    input_type=_GETVARREQUEST,
    output_type=_GETVARGRIDRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getVarType',
    full_name='bmi.BmiService.getVarType',
    index=14,
    containing_service=None,
    input_type=_GETVARREQUEST,
    output_type=_GETVARTYPERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getVarItemSize',
    full_name='bmi.BmiService.getVarItemSize',
    index=15,
    containing_service=None,
    input_type=_GETVARREQUEST,
    output_type=_GETVARITEMSIZERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getVarUnits',
    full_name='bmi.BmiService.getVarUnits',
    index=16,
    containing_service=None,
    input_type=_GETVARREQUEST,
    output_type=_GETVARUNITSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getVarNBytes',
    full_name='bmi.BmiService.getVarNBytes',
    index=17,
    containing_service=None,
    input_type=_GETVARREQUEST,
    output_type=_GETVARNBYTESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getValue',
    full_name='bmi.BmiService.getValue',
    index=18,
    containing_service=None,
    input_type=_GETVARREQUEST,
    output_type=_GETVALUERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getValueAtIndices',
    full_name='bmi.BmiService.getValueAtIndices',
    index=19,
    containing_service=None,
    input_type=_GETVALUEATINDICESREQUEST,
    output_type=_GETVALUEATINDICESRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setValue',
    full_name='bmi.BmiService.setValue',
    index=20,
    containing_service=None,
    input_type=_SETVALUEREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='setValueAtIndices',
    full_name='bmi.BmiService.setValueAtIndices',
    index=21,
    containing_service=None,
    input_type=_SETVALUEATINDICESREQUEST,
    output_type=_EMPTY,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridSize',
    full_name='bmi.BmiService.getGridSize',
    index=22,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDSIZERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridType',
    full_name='bmi.BmiService.getGridType',
    index=23,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDTYPERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridRank',
    full_name='bmi.BmiService.getGridRank',
    index=24,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDRANKRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridShape',
    full_name='bmi.BmiService.getGridShape',
    index=25,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDSHAPERESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridSpacing',
    full_name='bmi.BmiService.getGridSpacing',
    index=26,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDSPACINGRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridOrigin',
    full_name='bmi.BmiService.getGridOrigin',
    index=27,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDORIGINRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridX',
    full_name='bmi.BmiService.getGridX',
    index=28,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDPOINTSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridY',
    full_name='bmi.BmiService.getGridY',
    index=29,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDPOINTSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridZ',
    full_name='bmi.BmiService.getGridZ',
    index=30,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDPOINTSRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridConnectivity',
    full_name='bmi.BmiService.getGridConnectivity',
    index=31,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDCONNECTIVITYRESPONSE,
    options=None,
  ),
  _descriptor.MethodDescriptor(
    name='getGridOffset',
    full_name='bmi.BmiService.getGridOffset',
    index=32,
    containing_service=None,
    input_type=_GRIDREQUEST,
    output_type=_GETGRIDOFFSETRESPONSE,
    options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_BMISERVICE)

DESCRIPTOR.services_by_name['BmiService'] = _BMISERVICE

# @@protoc_insertion_point(module_scope)
